#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.1.17
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_ver_major_minor %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1 | cut -d "." -f 1,2)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXfixes-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 14.2
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-devel
BuildRequires:	qubes-gui-common-devel >= 4.1.0
BuildRequires:	qubes-db-devel
BuildRequires:	xen-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	libXfixes
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan
# qubesdb-read --wait option
Requires:	qubes-db >= 4.1.4
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-utils
Requires:   xorg-x11-server-Xorg
Requires:   xorg-x11-server-Xephyr
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make appvm

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-run-xephyr
/usr/bin/qubes-start-xephyr
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%{_libdir}/libxf86-qubes-common.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/X11/xinit/xinitrc.d/50guivm-windows-prefix.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
/etc/qubes-rpc/qubes.GuiVMSession
/etc/qubes/post-install.d/20-qubes-guivm-gui-agent.sh
%config /etc/sysconfig/desktop
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
/usr/lib/qubes/qubes-gui-agent-pre.sh
/usr/lib/qubes/qubes-keymap.sh
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
/etc/xdg/autostart/qubes-qrexec-fork-server.desktop
/etc/xdg/autostart/qubes-keymap.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver_major_minor}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/60xfce-desktop.sh

%changelog
* Mon Apr 05 2021 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux.git

* Mon Apr 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b1c7f38
- version 4.1.17

* Fri Mar 12 2021 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - bb38359
- get-latest-pulsecore: default value for latest Fedora release

* Sun Mar 07 2021 Rusty Bird <rustybird@net-c.com> - 0b5f831
- vmside: make strncat() length more obvious

* Sat Feb 13 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f825ad9
- version 4.1.16

* Mon Jan 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 291f697
- Add pulseaudio 14.2 headers

* Mon Jan 18 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 057bef2
- Add pulseaudio-14.1 headers

* Sun Jan 17 2021 unman <unman@thirdeyesecurity.org> - f9f03ba
- Fix pulseaudio in Ubuntu templates

* Fri Jan 08 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ac6778d
- debian: prevent restart on update

* Tue Jan 05 2021 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3d2e1cd
- version 4.1.15

* Thu Dec 31 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 56f1b43
- Mass replace: ‘/var/run’ → ‘/run’

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - ac6b71e
- Remove unneded time parameters

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - ab398bd
- Avoid passing NULL as an X11 string

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 6a5378c
- Remove references to /tmp/qubes-session-{env,waiter}

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 14e93a5
- Tell Java we are a non-reparenting window manager

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - f84093a
- Only set focus on windows that want it

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - cc2a426
- Use actual X11 timestamps

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 19ce958
- Delete commented-out code

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 7391391
- Add Vim modeline

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 39da627
- Log when an unmanaged window is skipped

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 2984496
- Move XInternAtom calls to startup

* Thu Dec 17 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - 1c2ea23
- Remove unnecessary XInternAtom

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 39bc4cf
- debian: update compat

* Sat Dec 12 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 8cfa43d
- debian: update control

* Fri Dec 11 2020 Benjamin Moody <benjaminmoody@gmail.com> - 585fa45
- vmside: Implement the WM_STATE property.

* Fri Dec 11 2020 Benjamin Moody <benjaminmoody@gmail.com> - ea4931e
- vmside: Rename wm_state to net_wm_state.

* Thu Dec 03 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 70a8f14
- version 4.1.14

* Thu Dec 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 51da0da
- Refactor main Makefile

* Thu Dec 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f38e9b2
- Allow to override defined CFLAGS

* Thu Dec 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3195236
- Few improvements from Marek's suggestions

* Thu Dec 03 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - b873646
- Fix indentation and segfault

* Wed Dec 02 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 1a5df71
- Add pulseaudio-14.0 headers

* Wed Dec 02 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f0f7d06
- Add script for getting latest pulsecore headers

* Wed Dec 02 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - efacf26
- Make variables static and add extern declaration

* Wed Dec 02 2020 Demi Marie Obenour <athena@invisiblethingslab.com> - febd112
- Fix Unicode handling in Qubes clipboard

* Wed Nov 25 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8fc6456
- gitlab-ci: exclude qubes-gui-agent when installing in dom0

* Sun Nov 15 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c8848bb
- Add .gitlab-ci.yml

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 53029ef
- Use pkg-config to get BACKEND_VMM

* Sat Nov 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - ec44034
- Set default BACKEND_VMM value to xen

* Sat Nov 14 2020 icequbes1 <71958531+icequbes1@users.noreply.github.com> - 2685613
- [ubuntu] Perform quilt refresh for ubuntu-only patch

* Thu Nov 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 285a0a7
- Start gui-agent only after systemd let in normal users

* Tue Nov 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1be1798
- xf86-video-dummy: improve error message on xengntshr_open fail

* Sun Nov 01 2020 icequbes1 <71958531+icequbes1@users.noreply.github.com> - c2387c3
- Link pulsecore 13.99.3 headers to 13.99.2

* Thu Oct 29 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d5d483d
- version 4.1.13

* Sun Oct 18 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - d73b021
- Fix archlinux packaging

* Sat Oct 17 2020 unman <unman@thirdeyesecurity.org> - ae26033
- pulseaudio 13.99.2

* Sat Oct 17 2020 unman <unman@thirdeyesecurity.org> - 913cf55
- pulseaudio 13.99.2: add internal headers

* Sat Oct 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 613cb11
- version 4.1.12

* Sat Oct 03 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 8cfea36
- pulseaudio: allow bluetooth devices like headphones

* Fri Aug 21 2020 Matt McCutchen <matt@mattmccutchen.net> - 391160e
- module-vchan-sink: link up the card properly

* Thu Aug 06 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fc9e074
- version 4.1.11

